@@ -184,6 +184,10 @@ namespace awkward {
     virtual const std::vector<std::string>
       keys() const = 0;
 
+    /// @brief Returns `true` if the outermost RecordArray is a tuple
+    virtual bool
+      istuple() const = 0;
+
     /// @brief Returns a string representation of this Form (#tojson with
     /// `pretty = true` and `verbose = false`).
     virtual const std::string
@@ -623,6 +627,10 @@ namespace awkward {
     virtual const std::vector<std::string>
       keys() const = 0;
 
+    /// @brief Returns `true` if the outermost RecordArray is a tuple
+    virtual bool
+      istuple() const = 0;
+
     /// @brief Returns an error message if this array is invalid; otherwise,
     /// returns an empty string.
     virtual const std::string
@@ -813,7 +821,7 @@ namespace awkward {
                   bool mask,
                   bool keepdims) const = 0;
 
-    /// @brief This array with one axis removed by applying a Reducer
+    /// @brief This array sorted
     ///
     /// The user's entry point for this operation is #sort.
     ///
@@ -824,7 +832,7 @@ namespace awkward {
     /// structure into this structure with the same meaning as in
     /// {@link ListArrayOf ListArray}.
     /// @param parents Groups to combine as an {@link IndexOf Index} of
-    /// upward pointers from this structure to the outer structure to reduce.
+    /// upward pointers from this structure to the outer structure to sort.
     /// @param outlength The length of the array, after the operation
     /// completes.
     /// @param ascending If `true`, the values will be sorted in an ascending
@@ -838,17 +846,38 @@ namespace awkward {
                 const Index64& parents,
                 int64_t outlength,
                 bool ascending,
-                bool stable,
-                bool keepdims) const = 0;
+                bool stable) const = 0;
 
+    /// @brief This array sorted indices
+    ///
+    /// The user's entry point for this operation is #argsort.
+    ///
+    /// @param negaxis The negative axis: `-axis`. That is, `negaxis = 1`
+    /// means the deepest axis level.
+    /// @param starts Staring positions of each group to combine as an
+    /// {@link IndexOf Index}. These are downward pointers from an outer
+    /// structure into this structure with the same meaning as in
+    /// {@link ListArrayOf ListArray}.
+    /// @param shifts Per-element adjustments that allows
+    /// for variable-length lists with axis != -1 and for missing values
+    /// (None).
+    /// @param parents Groups to combine as an {@link IndexOf Index} of
+    /// upward pointers from this structure to the outer structure to sort.
+    /// @param outlength The length of the array, after the operation
+    /// completes.
+    /// @param ascending If `true`, the values will be sorted in an ascending
+    /// order.
+    /// @param stable If `true`, the values will be sorted by a
+    /// stable sort algorithm to maintain the relative order of records with
+    /// equal keys (i.e. values).
     virtual const ContentPtr
       argsort_next(int64_t negaxis,
                    const Index64& starts,
+                   const Index64& shifts,
                    const Index64& parents,
                    int64_t outlength,
                    bool ascending,
-                   bool stable,
-                   bool keepdims) const = 0;
+                   bool stable) const = 0;
 
     /// @brief A (possibly nested) array of integers indicating the
     /// positions of elements within each nested list.
@@ -1319,32 +1348,6 @@ namespace awkward {
                           const SliceJagged64& slicecontent,
                           const Slice& tail) const = 0;
 
-    /// @brief Internal function that propagates a jagged array (array with
-    /// irregular-length dimensions) slice through one axis.
-    ///
-    /// See generic #getitem_next_jagged for details.
-    virtual const ContentPtr
-      getitem_next_jagged(const Index64& slicestarts,
-                          const Index64& slicestops,
-                          const SliceVarNewAxis& slicecontent,
-                          const Slice& tail) const = 0;
-
-    /// @brief Internal function that propagates a generic #getitem request
-    /// through one axis (including advanced indexing).
-    ///
-    /// See generic #getitem_next for details.
-    virtual const ContentPtr
-      getitem_next(const SliceVarNewAxis& varnewaxis,
-                   const Slice& tail,
-                   const Index64& advanced) const = 0;
-
-    /// @brief Internal function to convert a SliceVarNewAxis into the
-    /// right-sized SliceJagged64 for a given Content.
-    ///
-    /// See generic #getitem_next_jagged for details.
-    virtual const SliceJagged64
-      varaxis_to_jagged(const SliceVarNewAxis& varnewaxis) const = 0;
-
     /// @brief Internal function defining the negative axis handling for many
     /// operations.
     ///
