@@ -156,6 +156,10 @@ namespace awkward {
     const std::vector<std::string>
       keys() const override;
 
+    /// @exception std::runtime_error is always thrown
+    bool
+      istuple() const override;
+
     // operations
 
     /// @exception std::runtime_error is always thrown
@@ -222,17 +226,16 @@ namespace awkward {
                 const Index64& parents,
                 int64_t outlength,
                 bool ascending,
-                bool stable,
-                bool keepdims) const override;
+                bool stable) const override;
 
     const ContentPtr
       argsort_next(int64_t negaxis,
                    const Index64& starts,
+                   const Index64& shifts,
                    const Index64& parents,
                    int64_t outlength,
                    bool ascending,
-                   bool stable,
-                   bool keepdims) const override;
+                   bool stable) const override;
 
     /// @exception std::runtime_error is always thrown
     const ContentPtr
@@ -304,21 +307,6 @@ namespace awkward {
                           const SliceJagged64& slicecontent,
                           const Slice& tail) const override;
 
-    /// @exception std::runtime_error is always thrown
-    const ContentPtr
-      getitem_next_jagged(const Index64& slicestarts,
-                          const Index64& slicestops,
-                          const SliceVarNewAxis& slicecontent,
-                          const Slice& tail) const override;
-
-    const ContentPtr
-      getitem_next(const SliceVarNewAxis& varnewaxis,
-                   const Slice& tail,
-                   const Index64& advanced) const override;
-
-    const SliceJagged64
-      varaxis_to_jagged(const SliceVarNewAxis& varnewaxis) const override;
-
     const ContentPtr
       copy_to(kernel::lib ptr_lib) const override;
 
