@@ -4,8 +4,8 @@
 #define AWKWARD_COMPLEX128BUILDER_H_
 
 #include "awkward/common.h"
-#include "awkward/builder/ArrayBuilderOptions.h"
-#include "awkward/builder/GrowableBuffer.h"
+#include "awkward/BuilderOptions.h"
+#include "awkward/GrowableBuffer.h"
 #include "awkward/builder/Builder.h"
 
 #include <complex>
@@ -20,14 +20,14 @@ namespace awkward {
     /// @param options Configuration options for building an array;
     /// these are passed to every Builder's constructor.
     static const BuilderPtr
-      fromempty(const ArrayBuilderOptions& options);
+      fromempty(const BuilderOptions& options);
 
     /// @brief Create a Complex128Builder from an existing Int64Builder.
     /// @param options Configuration options for building an array;
     /// these are passed to every Builder's constructor.
     /// @param old The Int64Builder's buffer.
     static const BuilderPtr
-      fromint64(const ArrayBuilderOptions& options,
+      fromint64(const BuilderOptions& options,
                 const GrowableBuffer<int64_t>& old);
 
     /// @brief Create a Complex128Builder from an existing Float64Builder.
@@ -35,7 +35,7 @@ namespace awkward {
     /// these are passed to every Builder's constructor.
     /// @param old The Float64Builder's buffer.
     static const BuilderPtr
-      fromfloat64(const ArrayBuilderOptions& options,
+      fromfloat64(const BuilderOptions& options,
                   const GrowableBuffer<double>& old);
 
     /// @brief Create a Complex128Builder from a full set of parameters.
@@ -43,13 +43,16 @@ namespace awkward {
     /// @param options Configuration options for building an array;
     /// these are passed to every Builder's constructor.
     /// @param buffer Contains the accumulated real numbers.
-    Complex128Builder(const ArrayBuilderOptions& options,
-                      const GrowableBuffer<std::complex<double>>& buffer);
+    Complex128Builder(const BuilderOptions& options,
+                      GrowableBuffer<std::complex<double>> buffer);
 
     /// @brief User-friendly name of this class: `"Complex128Builder"`.
     const std::string
       classname() const override;
 
+    const std::string
+      to_buffers(BuffersContainer& container, int64_t& form_key_id) const override;
+
     int64_t
       length() const override;
 
@@ -104,22 +107,19 @@ namespace awkward {
     const BuilderPtr
       beginrecord(const char* name, bool check) override;
 
-    const BuilderPtr
+    void
       field(const char* key, bool check) override;
 
     const BuilderPtr
       endrecord() override;
 
-    const BuilderPtr
-      append(const ContentPtr& array, int64_t at) override;
-
-    const ArrayBuilderOptions&
+    const BuilderOptions&
       options() const { return options_; }
 
     const GrowableBuffer<std::complex<double>>& buffer() const { return buffer_; }
 
   private:
-    const ArrayBuilderOptions options_;
+    const BuilderOptions options_;
     GrowableBuffer<std::complex<double>> buffer_;
   };
 
