@@ -191,6 +191,26 @@ namespace awkward {
       }
     }
 
+    template<class T>
+    using UniquePtrDeleter = decltype(kernel::array_deleter<T>());
+    template<class T>
+    using UniquePtr = std::unique_ptr<T, UniquePtrDeleter<T>>;
+
+    template <typename T>
+    UniquePtr<T> unique_malloc(
+      kernel::lib ptr_lib,
+      int64_t bytelength) {
+      if (ptr_lib == lib::cpu) {
+        return UniquePtr<T>(
+          reinterpret_cast<T*>(awkward_malloc(bytelength)),
+          kernel::array_deleter<T>());
+      }
+      else {
+        throw std::runtime_error(
+          std::string("unrecognized ptr_lib in ptr_alloc<bool>"));
+      }
+    }
+
     /////////////////////////////////// awkward/kernels/getitem.h
 
     /// @brief Internal utility kernel to avoid raw pointer access.
@@ -296,6 +316,15 @@ namespace awkward {
       int64_t stride,
       const int64_t* pos);
 
+    ERROR NumpyArray_contiguous_copy_from_many_64(
+      kernel::lib ptr_lib,
+      uint8_t* toptr,
+      const uint8_t** fromptrs,
+      int64_t* fromlens,
+      int64_t len,
+      int64_t stride,
+      const int64_t* pos);
+
     ERROR NumpyArray_contiguous_next_64(
       kernel::lib ptr_lib,
       int64_t* topos,
@@ -520,6 +549,20 @@ namespace awkward {
       int64_t lencarry,
       int64_t size);
 
+    ERROR RegularArray_reduce_local_nextparents_64(
+        kernel::lib ptr_lib,
+        int64_t* nextparents,
+        int64_t size,
+        int64_t length);
+
+    ERROR RegularArray_reduce_nonlocal_preparenext_64(
+        kernel::lib ptr_lib,
+        int64_t* nextcarry,
+        int64_t* nextparents,
+        const int64_t* parents,
+        int64_t size,
+        int64_t length);
+
     template <typename T>
     ERROR IndexedArray_numnull(
       kernel::lib ptr_lib,
@@ -527,6 +570,15 @@ namespace awkward {
       const T* fromindex,
       int64_t lenindex);
 
+    template <typename T>
+    ERROR IndexedArray_index_of_nulls(
+      kernel::lib ptr_lib,
+      int64_t* toindex,
+      const T* fromindex,
+      int64_t lenindex,
+      const int64_t* parents,
+      const int64_t* starts);
+
     template <typename T>
     ERROR IndexedArray_getitem_nextcarry_outindex_64(
       kernel::lib ptr_lib,
@@ -1079,6 +1131,28 @@ namespace awkward {
       const bool* fromptr,
       int64_t length);
 
+    template <typename FROM, typename TO>
+    ERROR NumpyArray_fill_scaled(
+      kernel::lib ptr_lib,
+      TO* toptr,
+      int64_t tooffset,
+      const FROM* fromptr,
+      int64_t length,
+      double scale);
+
+    template <typename FROM, typename TO>
+    ERROR NumpyArray_rearrange_shifted(
+      kernel::lib ptr_lib,
+      TO* toptr,
+      const FROM* fromshifts,
+      int64_t length,
+      const FROM* fromoffsets,
+      int64_t offsetslength,
+      const FROM* fromparents,
+      int64_t parentslength,
+      const FROM* fromstarts,
+      int64_t startslength);
+
     template <typename FROM, typename TO>
     ERROR ListArray_fill(
       kernel::lib ptr_lib,
@@ -1249,6 +1323,11 @@ namespace awkward {
       int64_t target,
       int64_t length);
 
+    ERROR Index_nones_as_index_64(
+      kernel::lib ptr_lib,
+      int64_t* toindex,
+      int64_t length);
+
     ERROR RegularArray_rpad_and_clip_axis1_64(
       kernel::lib ptr_lib,
       int64_t* toindex,
@@ -1256,12 +1335,6 @@ namespace awkward {
       int64_t size,
       int64_t length);
 
-    ERROR SliceVarNewAxis_to_SliceJagged64(
-      kernel::lib ptr_lib,
-      int64_t* tocarry,
-      const int64_t* fromoffsets,
-      int64_t length);
-
     template <typename T>
     ERROR ListArray_min_range(
       kernel::lib ptr_lib,
@@ -1333,29 +1406,6 @@ namespace awkward {
       int64_t size,
       int64_t length);
 
-    template <typename T>
-    ERROR carry_SliceJagged_offsets(
-      kernel::lib ptr_lib,
-      T* tooffsets,
-      const T* fromoffsets,
-      const int64_t* fromcarry,
-      int64_t carrylen);
-
-    template <typename T>
-    ERROR carry_SliceJagged_nextcarry(
-      kernel::lib ptr_lib,
-      int64_t* tocarry,
-      const T* fromoffsets,
-      const int64_t* fromcarry,
-      int64_t carrylen);
-
-    template <typename T>
-    ERROR carry_SliceMissing_outindex(
-      kernel::lib ptr_lib,
-      int64_t* toindex,
-      const T* fromindex,
-      int64_t length);
-
     template <typename T>
     ERROR combinations(
       kernel::lib ptr_lib,
@@ -1552,19 +1602,12 @@ namespace awkward {
       const int64_t* nextparents,
       int64_t nextlen);
 
-    ERROR ListOffsetArray_reduce_nonlocal_findgaps_64(
-      kernel::lib ptr_lib,
-      int64_t* gaps,
-      const int64_t* parents,
-      int64_t lenparents);
-
     ERROR ListOffsetArray_reduce_nonlocal_outstartsstops_64(
       kernel::lib ptr_lib,
       int64_t* outstarts,
       int64_t* outstops,
       const int64_t* distincts,
       int64_t lendistincts,
-      const int64_t* gaps,
       int64_t outlength);
 
     ERROR ListOffsetArray_reduce_nonlocal_nextshifts_64(
@@ -1779,6 +1822,18 @@ namespace awkward {
       bool ascending,
       bool stable);
 
+    ERROR ListOffsetArray_argsort_strings(
+      kernel::lib ptr_lib,
+      int64_t* tocarry,
+      const int64_t* fromparents,
+      int64_t length,
+      const uint8_t* stringdata,
+      const int64_t* stringstarts,
+      const int64_t* stringstops,
+      bool is_stable,
+      bool is_ascending,
+      bool is_local);
+
     template <typename T>
     ERROR NumpyArray_sort_asstrings(
       kernel::lib ptr_lib,
