@@ -6,7 +6,6 @@ import awkward as ak
 from awkward._v2.index import Index
 from awkward._v2.contents.content import Content, unset
 from awkward._v2.forms.listoffsetform import ListOffsetForm
-from awkward._v2.forms.form import _parameters_equal
 
 np = ak.nplike.NumpyMetadata.instance()
 numpy = ak.nplike.Numpy.instance()
@@ -31,6 +30,17 @@ class ListOffsetArray(Content):
             self._nplike if nplike is unset else nplike,
         )
 
+    def __copy__(self):
+        return self.copy()
+
+    def __deepcopy__(self, memo):
+        return self.copy(
+            offsets=copy.deepcopy(self._offsets, memo),
+            content=copy.deepcopy(self._content, memo),
+            identifier=copy.deepcopy(self._identifier, memo),
+            parameters=copy.deepcopy(self._parameters, memo),
+        )
+
     def __init__(self, offsets, content, identifier=None, parameters=None, nplike=None):
         if not isinstance(offsets, Index) and offsets.dtype in (
             np.dtype(np.int32),
@@ -723,20 +733,8 @@ class ListOffsetArray(Content):
                     ),
                 )
 
-    def mergeable(self, other, mergebool):
-        if not _parameters_equal(self._parameters, other._parameters):
-            return False
-
+    def _mergeable(self, other, mergebool):
         if isinstance(
-            other,
-            (
-                ak._v2.contents.emptyarray.EmptyArray,
-                ak._v2.contents.unionarray.UnionArray,
-            ),
-        ):
-            return True
-
-        elif isinstance(
             other,
             (
                 ak._v2.contents.indexedarray.IndexedArray,
@@ -1487,7 +1485,6 @@ class ListOffsetArray(Content):
 
         branch, depth = self.branch_depth
         globalstarts_length = self._offsets.length - 1
-        parents_length = parents.length
 
         if not branch and negaxis == depth:
             (
@@ -1499,27 +1496,12 @@ class ListOffsetArray(Content):
                 nextstarts,
             ) = self._rearrange_prepare_next(outlength, parents)
 
-            gaps = ak._v2.index.Index64.empty(outlength, self._nplike)
-            assert gaps.nplike is self._nplike and parents.nplike is self._nplike
-            self._handle_error(
-                self._nplike[
-                    "awkward_ListOffsetArray_reduce_nonlocal_findgaps_64",
-                    gaps.dtype.type,
-                    parents.dtype.type,
-                ](
-                    gaps.data,
-                    parents.data,
-                    parents_length,
-                )
-            )
-
             outstarts = ak._v2.index.Index64.empty(outlength, self._nplike)
             outstops = ak._v2.index.Index64.empty(outlength, self._nplike)
             assert (
                 outstarts.nplike is self._nplike
                 and outstops.nplike is self._nplike
                 and distincts.nplike is self._nplike
-                and gaps.nplike is self._nplike
             )
             self._handle_error(
                 self._nplike[
@@ -1527,13 +1509,11 @@ class ListOffsetArray(Content):
                     outstarts.dtype.type,
                     outstops.dtype.type,
                     distincts.dtype.type,
-                    gaps.dtype.type,
                 ](
                     outstarts.data,
                     outstops.data,
                     distincts.data,
                     distincts.length,
-                    gaps.data,
                     outlength,
                 )
             )
@@ -1608,7 +1588,7 @@ class ListOffsetArray(Content):
                     None,
                     None,
                     self._nplike,
-                ).toListOffsetArray64(False)
+                )
 
             return out
 
@@ -1662,13 +1642,16 @@ class ListOffsetArray(Content):
                 )
             )
 
-            represents_regular = getattr(self, "_represents_regular", False)
-
-            if keepdims and (
-                not represents_regular or self._content.dimension_optiontype
-            ):
-                if isinstance(outcontent, ak._v2.contents.RegularArray):
-                    outcontent = outcontent.toListOffsetArray64(False)
+            # `outcontent` represents *this* layout in the reduction
+            # If this layout survives in the reduction (see `if` below), then we want
+            # to ensure that we have a ragged list type (unless it's a `keepdims=True` layout)
+            if keepdims and depth == negaxis + 1:
+                # Don't convert the `RegularArray()` to a `ListOffsetArray`,
+                # means this will be broadcastable
+                assert outcontent.is_RegularType
+            elif depth >= negaxis + 2:
+                assert outcontent.is_ListType or outcontent.is_RegularType
+                outcontent = outcontent.toListOffsetArray64(False)
 
             return ak._v2.contents.ListOffsetArray(
                 outoffsets,
@@ -1701,8 +1684,9 @@ class ListOffsetArray(Content):
             )
         )
 
-        np_nextcarry = self._nplike.index_nplike.empty(nextlen, dtype=np.int64)
-        np_nextparents = self._nplike.index_nplike.empty(nextlen, dtype=np.int64)
+        # A "stable" sort is essential for the subsequent steps.
+        nextcarry = ak._v2.index.Index64.empty(nextlen, nplike=self._nplike)
+        nextparents = ak._v2.index.Index64.empty(nextlen, nplike=self._nplike)
         maxnextparents = ak._v2.index.Index64.empty(1, self._nplike)
         distincts = ak._v2.index.Index64.empty(outlength * maxcount[0], self._nplike)
         assert (
@@ -1715,16 +1699,16 @@ class ListOffsetArray(Content):
         self._handle_error(
             self._nplike[
                 "awkward_ListOffsetArray_reduce_nonlocal_preparenext_64",
-                np_nextcarry.dtype.type,
-                np_nextparents.dtype.type,
+                nextcarry.dtype.type,
+                nextparents.dtype.type,
                 maxnextparents.dtype.type,
                 distincts.dtype.type,
                 self._offsets.dtype.type,
                 offsetscopy.dtype.type,
                 parents.dtype.type,
             ](
-                np_nextcarry,
-                np_nextparents,
+                nextcarry.data,
+                nextparents.data,
                 nextlen,
                 maxnextparents.data,
                 distincts.data,
@@ -1736,10 +1720,6 @@ class ListOffsetArray(Content):
                 maxcount[0],
             )
         )
-        # A "stable" sort is essential for the subsequent steps.
-        reorder = self._nplike.index_nplike.argsort(np_nextparents, kind="stable")
-        nextcarry = ak._v2.index.Index64(np_nextcarry[reorder], nplike=self.nplike)
-        nextparents = ak._v2.index.Index64(np_nextparents[reorder], nplike=self.nplike)
         nextstarts = ak._v2.index.Index64.empty(maxnextparents[0] + 1, self._nplike)
         assert nextstarts.nplike is self._nplike and nextparents.nplike is self._nplike
         self._handle_error(
