@@ -119,6 +119,11 @@ namespace awkward {
     return std::vector<std::string>();
   }
 
+  bool
+  EmptyForm::istuple() const {
+    return false;
+  }
+
   bool
   EmptyForm::equal(const FormPtr& other,
                    bool check_identities,
@@ -427,6 +432,11 @@ namespace awkward {
     return std::vector<std::string>();
   }
 
+  bool
+  EmptyArray::istuple() const {
+    return false;
+  }
+
   const std::string
   EmptyArray::validityerror(const std::string& path) const {
     const std::string paramcheck = validityerror_parameters(path);
