@@ -255,12 +255,10 @@ namespace awkward {
   ListOffsetArrayOf<T>::ListOffsetArrayOf(const IdentitiesPtr& identities,
                                           const util::Parameters& parameters,
                                           const IndexOf<T>& offsets,
-                                          const ContentPtr& content,
-                                          bool represents_regular)
+                                          const ContentPtr& content)
       : Content(identities, parameters)
       , offsets_(offsets)
-      , content_(content)
-      , represents_regular_(represents_regular) {
+      , content_(content) {
     if (offsets.length() == 0) {
       throw std::invalid_argument(
         std::string("ListOffsetArray offsets length must be at least 1")
@@ -1441,25 +1439,16 @@ namespace awkward {
         nextlen);
       util::handle_error(err4, classname(), identities_.get());
 
-      Index64 gaps(outlength);
-      struct Error err5 = kernel::ListOffsetArray_reduce_nonlocal_findgaps_64(
-        kernel::lib::cpu,   // DERIVE
-        gaps.data(),
-        parents.data(),
-        parents.length());
-      util::handle_error(err5, classname(), identities_.get());
-
       Index64 outstarts(outlength);
       Index64 outstops(outlength);
-      struct Error err6 = kernel::ListOffsetArray_reduce_nonlocal_outstartsstops_64(
+      struct Error err5 = kernel::ListOffsetArray_reduce_nonlocal_outstartsstops_64(
         kernel::lib::cpu,   // DERIVE
         outstarts.data(),
         outstops.data(),
         distincts.data(),
         maxcount * outlength,
-        gaps.data(),
         outlength);
-      util::handle_error(err6, classname(), identities_.get());
+      util::handle_error(err5, classname(), identities_.get());
 
       bool make_shifts = reducer.returns_positions();
 
@@ -1467,7 +1456,7 @@ namespace awkward {
       if (make_shifts) {
         Index64 nummissing(maxcount);
         Index64 missing(offsets_.getitem_at(offsets_.length() - 1));
-        struct Error err7 = kernel::ListOffsetArray_reduce_nonlocal_nextshifts_64(
+        struct Error err6 = kernel::ListOffsetArray_reduce_nonlocal_nextshifts_64(
           kernel::lib::cpu,   // DERIVE
           nummissing.data(),
           missing.data(),
@@ -1479,7 +1468,7 @@ namespace awkward {
           maxcount,
           nextlen,
           nextcarry.data());
-        util::handle_error(err7, classname(), identities_.get());
+        util::handle_error(err6, classname(), identities_.get());
       }
 
       ContentPtr nextcontent = content_.get()->carry(nextcarry, false);
@@ -1499,12 +1488,12 @@ namespace awkward {
                                                      outcontent);
 
       if (keepdims) {
-        out = RegularArray(Identities::none(),
+        out = std::make_shared<RegularArray>(Identities::none(),
                            util::Parameters(),
                            out,
                            1,
                            length()
-              ).toListOffsetArray64(false).get()->shallow_copy();
+              );
       }
 
       return out;
@@ -1533,7 +1522,7 @@ namespace awkward {
       ContentPtr trimmed = content_.get()->getitem_range_nowrap(globalstart,
                                                                 globalstop);
 
-      ContentPtr outcontent = trimmed.get()->reduce_next(reducer,
+      ContentPtr outcontent = trimmed->reduce_next(reducer,
                                                          negaxis,
                                                          util::make_starts(offsets_),
                                                          shifts,
@@ -1551,9 +1540,16 @@ namespace awkward {
         outlength);
       util::handle_error(err3, classname(), identities_.get());
 
-      if (keepdims  &&  (!represents_regular_  ||  content_.get()->dimension_optiontype())) {
+      if (keepdims  &&  (branchdepth.second == negaxis + 1)) {
         if (RegularArray* raw = dynamic_cast<RegularArray*>(outcontent.get())) {
-          outcontent = raw->toListOffsetArray64(false).get()->shallow_copy();
+          outcontent = raw->toListOffsetArray64(false);
+        } else {
+          throw std::invalid_argument(
+              std::string("expected regulararray") + FILENAME(__LINE__));
+        }
+      } else if (branchdepth.second >= negaxis + 2) {
+        if (RegularArray* raw = dynamic_cast<RegularArray*>(outcontent.get())) {
+          outcontent = raw->toListOffsetArray64(false);
         }
       }
 
