@@ -910,11 +910,7 @@ namespace awkward {
                              int64_t outlength,
                              bool mask,
                              bool keepdims) const {
-    ContentPtr next = content_;
-    if (RegularArray* raw = dynamic_cast<RegularArray*>(next.get())) {
-      next = raw->toListOffsetArray64(true);
-    }
-    return next.get()->reduce_next(reducer,
+    return content_.get()->reduce_next(reducer,
                                    negaxis,
                                    starts,
                                    shifts,
