@@ -4,17 +4,16 @@
 
 #include <stdexcept>
 
-#include "awkward/builder/ArrayBuilderOptions.h"
 #include "awkward/builder/OptionBuilder.h"
 #include "awkward/builder/UnionBuilder.h"
 #include "awkward/builder/UnknownBuilder.h"
+#include "awkward/util.h"
 
 #include "awkward/builder/RecordBuilder.h"
-#include "awkward/util.h"
 
 namespace awkward {
   const BuilderPtr
-  RecordBuilder::fromempty(const ArrayBuilderOptions& options) {
+  RecordBuilder::fromempty(const BuilderOptions& options) {
     return std::make_shared<RecordBuilder>(options,
                                            std::vector<BuilderPtr>(),
                                            std::vector<std::string>(),
@@ -27,7 +26,7 @@ namespace awkward {
                                            -1);
   }
 
-  RecordBuilder::RecordBuilder(const ArrayBuilderOptions& options,
+  RecordBuilder::RecordBuilder(const BuilderOptions& options,
                                const std::vector<BuilderPtr>& contents,
                                const std::vector<std::string>& keys,
                                const std::vector<const char*>& pointers,
@@ -64,6 +63,29 @@ namespace awkward {
     return "RecordBuilder";
   };
 
+  const std::string
+  RecordBuilder::to_buffers(BuffersContainer& container, int64_t& form_key_id) const {
+    std::stringstream form_key;
+    form_key << "node" << (form_key_id++);
+
+    std::stringstream out;
+    out << "{\"class\": \"RecordArray\", \"contents\": {";
+    for (size_t i = 0;  i < contents_.size();  i++) {
+      if (i != 0) {
+        out << ", ";
+      }
+      out << "" + util::quote(keys_[i]) + ": ";
+      out << contents_[i].get()->to_buffers(container, form_key_id);
+    }
+    out << "}, ";
+    if (!name_.empty()) {
+      out << "\"parameters\": {\"__record__\": " + util::quote(name_) + "}, ";
+    }
+    out << "\"form_key\": \"" + form_key.str() + "\"}";
+
+    return out.str();
+  }
+
   int64_t
   RecordBuilder::length() const {
     return length_;
@@ -95,7 +117,7 @@ namespace awkward {
     if (!begun_) {
       BuilderPtr out = OptionBuilder::fromvalids(options_, shared_from_this());
       out.get()->null();
-      return out;
+      return std::move(out);
     }
     else if (nextindex_ == -1) {
       throw std::invalid_argument(
@@ -108,7 +130,7 @@ namespace awkward {
     else {
       contents_[(size_t)nextindex_].get()->null();
     }
-    return shared_from_this();
+    return nullptr;
   }
 
   const BuilderPtr
@@ -116,7 +138,7 @@ namespace awkward {
     if (!begun_) {
       BuilderPtr out = UnionBuilder::fromsingle(options_, shared_from_this());
       out.get()->boolean(x);
-      return out;
+      return std::move(out);
     }
     else if (nextindex_ == -1) {
       throw std::invalid_argument(
@@ -129,7 +151,7 @@ namespace awkward {
     else {
       contents_[(size_t)nextindex_].get()->boolean(x);
     }
-    return shared_from_this();
+    return nullptr;
   }
 
   const BuilderPtr
@@ -137,7 +159,7 @@ namespace awkward {
     if (!begun_) {
       BuilderPtr out = UnionBuilder::fromsingle(options_, shared_from_this());
       out.get()->integer(x);
-      return out;
+      return std::move(out);
     }
     else if (nextindex_ == -1) {
       throw std::invalid_argument(
@@ -150,7 +172,7 @@ namespace awkward {
     else {
       contents_[(size_t)nextindex_].get()->integer(x);
     }
-    return shared_from_this();
+    return nullptr;
   }
 
   const BuilderPtr
@@ -158,7 +180,7 @@ namespace awkward {
     if (!begun_) {
       BuilderPtr out = UnionBuilder::fromsingle(options_, shared_from_this());
       out.get()->real(x);
-      return out;
+      return std::move(out);
     }
     else if (nextindex_ == -1) {
       throw std::invalid_argument(
@@ -171,7 +193,7 @@ namespace awkward {
     else {
       contents_[(size_t)nextindex_].get()->real(x);
     }
-    return shared_from_this();
+    return nullptr;
   }
 
   const BuilderPtr
@@ -179,7 +201,7 @@ namespace awkward {
     if (!begun_) {
       BuilderPtr out = UnionBuilder::fromsingle(options_, shared_from_this());
       out.get()->complex(x);
-      return out;
+      return std::move(out);
     }
     else if (nextindex_ == -1) {
       throw std::invalid_argument(
@@ -192,7 +214,7 @@ namespace awkward {
     else {
       contents_[(size_t)nextindex_].get()->complex(x);
     }
-    return shared_from_this();
+    return nullptr;
   }
 
   const BuilderPtr
@@ -200,7 +222,7 @@ namespace awkward {
     if (!begun_) {
       BuilderPtr out = UnionBuilder::fromsingle(options_, shared_from_this());
       out.get()->datetime(x, unit);
-      return out;
+      return std::move(out);
     }
     else if (nextindex_ == -1) {
       throw std::invalid_argument(
@@ -213,7 +235,7 @@ namespace awkward {
     else {
       contents_[(size_t)nextindex_].get()->datetime(x, unit);
     }
-    return shared_from_this();
+    return nullptr;
   }
 
   const BuilderPtr
@@ -221,7 +243,7 @@ namespace awkward {
     if (!begun_) {
       BuilderPtr out = UnionBuilder::fromsingle(options_, shared_from_this());
       out.get()->timedelta(x, unit);
-      return out;
+      return std::move(out);
     }
     else if (nextindex_ == -1) {
       throw std::invalid_argument(
@@ -234,7 +256,7 @@ namespace awkward {
     else {
       contents_[(size_t)nextindex_].get()->timedelta(x, unit);
     }
-    return shared_from_this();
+    return nullptr;
   }
 
   const BuilderPtr
@@ -242,7 +264,7 @@ namespace awkward {
     if (!begun_) {
       BuilderPtr out = UnionBuilder::fromsingle(options_, shared_from_this());
       out.get()->string(x, length, encoding);
-      return out;
+      return std::move(out);
     }
     else if (nextindex_ == -1) {
       throw std::invalid_argument(
@@ -258,7 +280,7 @@ namespace awkward {
     else {
       contents_[(size_t)nextindex_].get()->string(x, length, encoding);
     }
-    return shared_from_this();
+    return nullptr;
   }
 
   const BuilderPtr
@@ -266,7 +288,7 @@ namespace awkward {
     if (!begun_) {
       BuilderPtr out = UnionBuilder::fromsingle(options_, shared_from_this());
       out.get()->beginlist();
-      return out;
+      return std::move(out);
     }
     else if (nextindex_ == -1) {
       throw std::invalid_argument(
@@ -307,7 +329,7 @@ namespace awkward {
     if (!begun_) {
       BuilderPtr out = UnionBuilder::fromsingle(options_, shared_from_this());
       out.get()->begintuple(numfields);
-      return out;
+      return std::move(out);
     }
     else if (nextindex_ == -1) {
       throw std::invalid_argument(
@@ -385,7 +407,7 @@ namespace awkward {
     else if (!begun_) {
       BuilderPtr out = UnionBuilder::fromsingle(options_, shared_from_this());
       out.get()->beginrecord(name, check);
-      return out;
+      return std::move(out);
     }
     else if (nextindex_ == -1) {
       throw std::invalid_argument(
@@ -404,17 +426,17 @@ namespace awkward {
     return shared_from_this();
   }
 
-  const BuilderPtr
+  void
   RecordBuilder::field(const char* key, bool check) {
     if (check) {
-      return field_check(key);
+      field_check(key);
     }
     else {
-      return field_fast(key);
+      field_fast(key);
     }
   }
 
-  const BuilderPtr
+  void
   RecordBuilder::field_fast(const char* key) {
     if (!begun_) {
       throw std::invalid_argument(
@@ -434,7 +456,7 @@ namespace awkward {
         if (pointers_[(size_t)i] == key) {
           nextindex_ = i;
           nexttotry_ = i + 1;
-          return shared_from_this();
+          return;
         }
         i++;
       } while (i != nexttotry_);
@@ -452,15 +474,15 @@ namespace awkward {
       keys_.push_back(std::string(key));
       pointers_.push_back(key);
       keys_size_ = (int64_t)keys_.size();
-      return shared_from_this();
+      return;
     }
     else {
       contents_[(size_t)nextindex_].get()->field(key, false);
-      return shared_from_this();
+      return;
     }
   }
 
-  const BuilderPtr
+  void
   RecordBuilder::field_check(const char* key) {
     if (!begun_) {
       throw std::invalid_argument(
@@ -480,29 +502,29 @@ namespace awkward {
         if (keys_[(size_t)i].compare(key) == 0) {
           nextindex_ = i;
           nexttotry_ = i + 1;
-          return shared_from_this();
+          return;
         }
         i++;
       } while (i != nexttotry_);
       nextindex_ = keys_size_;
       nexttotry_ = 0;
       if (length_ == 0) {
-        contents_.push_back(UnknownBuilder::fromempty(options_));
+        contents_.emplace_back(UnknownBuilder::fromempty(options_));
       }
       else {
-        contents_.push_back(
+        contents_.emplace_back(
           OptionBuilder::fromnulls(options_,
                                    length_,
                                    UnknownBuilder::fromempty(options_)));
       }
-      keys_.push_back(std::string(key));
-      pointers_.push_back(nullptr);
+      keys_.emplace_back(std::string(key));
+      pointers_.emplace_back(nullptr);
       keys_size_ = (int64_t)keys_.size();
-      return shared_from_this();
+      return;
     }
     else {
       contents_[(size_t)nextindex_].get()->field(key, true);
-      return shared_from_this();
+      return;
     }
   }
 
@@ -531,35 +553,13 @@ namespace awkward {
     else {
       contents_[(size_t)nextindex_].get()->endrecord();
     }
-    return shared_from_this();
-  }
-
-  const BuilderPtr
-  RecordBuilder::append(const ContentPtr& array, int64_t at) {
-    if (!begun_) {
-      BuilderPtr out = UnionBuilder::fromsingle(options_, shared_from_this());
-      out.get()->append(array, at);
-      return out;
-    }
-    else if (nextindex_ == -1) {
-      throw std::invalid_argument(
-        std::string("called 'append' immediately after 'begin_record'; "
-                    "needs 'index' or 'end_record'") + FILENAME(__LINE__));
-    }
-    else if (!contents_[(size_t)nextindex_].get()->active()) {
-      maybeupdate(nextindex_,
-                  contents_[(size_t)nextindex_].get()->append(array, at));
-    }
-    else {
-      contents_[(size_t)nextindex_].get()->append(array, at);
-    }
-    return shared_from_this();
+    return nullptr;
   }
 
   void
-  RecordBuilder::maybeupdate(int64_t i, const BuilderPtr& tmp) {
-    if (tmp.get() != contents_[(size_t)i].get()) {
-      contents_[(size_t)i] = tmp;
+  RecordBuilder::maybeupdate(int64_t i, const BuilderPtr tmp) {
+    if (tmp  &&  tmp.get() != contents_[(size_t)i].get()) {
+      contents_[(size_t)i] = std::move(tmp);
     }
   }
 }
