@@ -1,4 +1,6 @@
-// BSD 3-Clause License; see https://github.com/jpivarski/awkward-1.0/blob/master/LICENSE
+// BSD 3-Clause License; see https://github.com/scikit-hep/awkward-1.0/blob/main/LICENSE
+
+#define FILENAME(line) FILENAME_FOR_EXCEPTIONS("src/libawkward/type/RecordType.cpp", line)
 
 #include <string>
 #include <sstream>
@@ -8,6 +10,7 @@
 #include "awkward/type/UnknownType.h"
 #include "awkward/type/OptionType.h"
 #include "awkward/util.h"
+#include "awkward/virtual/ArrayCache.h"
 
 #include "awkward/type/RecordType.h"
 
@@ -22,7 +25,8 @@ namespace awkward {
     if (recordlookup_.get() != nullptr  &&
         recordlookup_.get()->size() != types_.size()) {
       throw std::runtime_error(
-        "recordlookup and types must have the same length");
+        std::string("recordlookup and types must have the same length")
+        + FILENAME(__LINE__));
     }
   }
 
@@ -64,7 +68,7 @@ namespace awkward {
                             const std::string& post) const {
     std::string typestr;
     if (get_typestr(typestr)) {
-      return typestr;
+      return wrap_categorical(typestr);
     }
 
     std::stringstream out;
@@ -80,23 +84,23 @@ namespace awkward {
             out << ", ";
           }
           if (recordlookup_.get() != nullptr) {
-            out << util::quote(recordlookup_.get()->at(j), true) << ": ";
+            out << util::quote(recordlookup_.get()->at(j)) << ": ";
           }
           out << types_[j].get()->tostring_part("", "", "");
         }
         out << "]";
-        return out.str();
+        return wrap_categorical(out.str());
       }
     }
 
-    if (parameters_.empty()) {
+    if (parameters_empty()) {
       if (recordlookup_.get() != nullptr) {
         out << "{";
         for (size_t j = 0;  j < types_.size();  j++) {
           if (j != 0) {
             out << ", ";
           }
-          out << util::quote(recordlookup_.get()->at(j), true) << ": ";
+          out << util::quote(recordlookup_.get()->at(j)) << ": ";
           out << types_[j].get()->tostring_part("", "", "");
         }
         out << "}";
@@ -119,7 +123,7 @@ namespace awkward {
           if (j != 0) {
             out << ", ";
           }
-          out << util::quote(recordlookup_.get()->at(j), true);
+          out << util::quote(recordlookup_.get()->at(j));
         }
         out << "], [";
         for (size_t j = 0;  j < types_.size();  j++) {
@@ -140,7 +144,7 @@ namespace awkward {
       }
       out << "], " << string_parameters() << "]";
     }
-    return out.str();
+    return wrap_categorical(out.str());
   }
 
   const TypePtr
@@ -154,7 +158,7 @@ namespace awkward {
   bool
   RecordType::equal(const TypePtr& other, bool check_parameters) const {
     if (RecordType* t = dynamic_cast<RecordType*>(other.get())) {
-      if (check_parameters  &&  !parameters_equal(other.get()->parameters())) {
+      if (check_parameters  &&  !parameters_equal(other.get()->parameters(), false)) {
         return false;
       }
       if (numfields() != t->numfields()) {
@@ -222,10 +226,13 @@ namespace awkward {
     for (auto type : types_) {
       contents.push_back(type.get()->empty());
     }
+    std::vector<ArrayCachePtr> caches;  // nothing is virtual here
     return std::make_shared<RecordArray>(Identities::none(),
                                          parameters_,
                                          contents,
-                                         recordlookup_);
+                                         recordlookup_,
+                                         0,
+                                         caches);
   }
 
   const TypePtr
@@ -234,7 +241,7 @@ namespace awkward {
       throw std::invalid_argument(
         std::string("fieldindex ") + std::to_string(fieldindex)
         + std::string(" for record with only ") + std::to_string(numfields())
-        + std::string(" fields"));
+        + std::string(" fields") + FILENAME(__LINE__));
     }
     return types_[(size_t)fieldindex];
   }
