@@ -1,4 +1,6 @@
-// BSD 3-Clause License; see https://github.com/jpivarski/awkward-1.0/blob/master/LICENSE
+// BSD 3-Clause License; see https://github.com/scikit-hep/awkward-1.0/blob/main/LICENSE
+
+#define FILENAME(line) FILENAME_FOR_EXCEPTIONS("src/libawkward/type/UnionType.cpp", line)
 
 #include <string>
 #include <sstream>
@@ -22,7 +24,7 @@ namespace awkward {
                            const std::string& post) const {
     std::string typestr;
     if (get_typestr(typestr)) {
-      return typestr;
+      return wrap_categorical(typestr);
     }
 
     std::stringstream out;
@@ -33,11 +35,11 @@ namespace awkward {
       }
       out << type(i).get()->tostring_part(indent, "", "");
     }
-    if (!parameters_.empty()) {
+    if (!parameters_empty()) {
       out << ", " << string_parameters();
     }
     out << "]" << post;
-    return out.str();
+    return wrap_categorical(out.str());
   }
 
   const TypePtr
@@ -48,7 +50,7 @@ namespace awkward {
   bool
   UnionType::equal(const TypePtr& other, bool check_parameters) const {
     if (UnionType* t = dynamic_cast<UnionType*>(other.get())) {
-      if (check_parameters  &&  !parameters_equal(other.get()->parameters())) {
+      if (check_parameters  &&  !parameters_equal(other.get()->parameters(), false)) {
         return false;
       }
       if (types_.size() != t->types_.size()) {
@@ -73,27 +75,32 @@ namespace awkward {
 
   int64_t
   UnionType::numfields() const {
-    throw std::runtime_error("FIXME: UnionType::numfields");
+    throw std::runtime_error(
+      std::string("FIXME: UnionType::numfields") + FILENAME(__LINE__));
   }
 
   int64_t
   UnionType::fieldindex(const std::string& key) const {
-    throw std::runtime_error("FIXME: UnionType::fieldindex(key)");
+    throw std::runtime_error(
+      std::string("FIXME: UnionType::fieldindex(key)") + FILENAME(__LINE__));
   }
 
   const std::string
   UnionType::key(int64_t fieldindex) const {
-    throw std::runtime_error("FIXME: UnionType::key(fieldindex)");
+    throw std::runtime_error(
+      std::string("FIXME: UnionType::key(fieldindex)") + FILENAME(__LINE__));
   }
 
   bool
   UnionType::haskey(const std::string& key) const {
-    throw std::runtime_error("FIXME: UnionType::haskey(key)");
+    throw std::runtime_error(
+      std::string("FIXME: UnionType::haskey(key)") + FILENAME(__LINE__));
   }
 
   const std::vector<std::string>
   UnionType::keys() const {
-    throw std::runtime_error("FIXME: UnionType::keys");
+    throw std::runtime_error(
+      std::string("FIXME: UnionType::keys") + FILENAME(__LINE__));
   }
 
   const std::vector<TypePtr>
