@@ -58,9 +58,9 @@ template <typename T>
 py::object
 parameter(const T& self, const std::string& key) {
   std::string cppvalue = self.parameter(key);
-  py::str pyvalue(PyUnicode_DecodeUTF8(cppvalue.data(),
-                                       cppvalue.length(),
-                                       "surrogateescape"));
+  py::str pyvalue = py::reinterpret_steal<py::str>(PyUnicode_DecodeUTF8(cppvalue.data(),
+                                        cppvalue.length(),
+                                        "surrogateescape"));
   return py::module::import("json").attr("loads")(pyvalue);
 }
 
