@@ -115,9 +115,9 @@ template <typename T>
 py::object
 parameter(const T& self, const std::string& key) {
   std::string cppvalue = self.parameter(key);
-  py::str pyvalue(PyUnicode_DecodeUTF8(cppvalue.data(),
-                                       cppvalue.length(),
-                                       "surrogateescape"));
+  py::str pyvalue = py::reinterpret_steal<py::str>(PyUnicode_DecodeUTF8(cppvalue.data(),
+                                        cppvalue.length(),
+                                        "surrogateescape"));
   return py::module::import("json").attr("loads")(pyvalue);
 }
 
@@ -125,9 +125,9 @@ template <typename T>
 py::object
 purelist_parameter(const T& self, const std::string& key) {
   std::string cppvalue = self.purelist_parameter(key);
-  py::str pyvalue(PyUnicode_DecodeUTF8(cppvalue.data(),
-                                       cppvalue.length(),
-                                       "surrogateescape"));
+  py::str pyvalue = py::reinterpret_steal<py::str>(PyUnicode_DecodeUTF8(cppvalue.data(),
+                                        cppvalue.length(),
+                                        "surrogateescape"));
   return py::module::import("json").attr("loads")(pyvalue);
 }
 
@@ -160,9 +160,9 @@ str2typestr(const std::string& in) {
     return py::none();
   }
   else {
-    py::str pyvalue(PyUnicode_DecodeUTF8(in.data(),
-                                         in.length(),
-                                         "surrogateescape"));
+    py::str pyvalue = py::reinterpret_steal<py::str>(PyUnicode_DecodeUTF8(in.data(),
+                                          in.length(),
+                                          "surrogateescape"));
     return pyvalue;
   }
 }
