@@ -1,7 +1,5 @@
 # BSD 3-Clause License; see https://github.com/scikit-hep/awkward-1.0/blob/main/LICENSE
 
-from __future__ import absolute_import
-
 import pytest  # noqa: F401
 import numpy as np  # noqa: F401
 import awkward as ak  # noqa: F401
@@ -98,13 +96,7 @@ def test_string2():
     assert isinstance(a, ak.Array)
     assert ak.to_list(a) == ["hey", "", "there"]
 
-    if ak._util.py27:
-        assert str(a) == "[u'hey', u'', u'there']"
-        assert repr(a[0]) == "u'hey'"
-        assert repr(a[1]) == "u''"
-        assert repr(a[2]) == "u'there'"
-    else:
-        assert str(a) == "['hey', '', 'there']"
-        assert repr(a[0]) == "'hey'"
-        assert repr(a[1]) == "''"
-        assert repr(a[2]) == "'there'"
+    assert str(a) == "['hey', '', 'there']"
+    assert repr(a[0]) == "'hey'"
+    assert repr(a[1]) == "''"
+    assert repr(a[2]) == "'there'"
