@@ -1,7 +1,5 @@
 # BSD 3-Clause License; see https://github.com/scikit-hep/awkward-1.0/blob/main/LICENSE
 
-from __future__ import absolute_import
-
 import pickle
 
 import pytest  # noqa: F401
@@ -9,7 +7,6 @@ import numpy as np  # noqa: F401
 import awkward as ak  # noqa: F401
 
 
-@pytest.mark.skipif(ak._util.py27, reason="pybind11 pickle only works in Python 3")
 def test_pickle():
     t = ak.types.UnknownType()
     assert pickle.loads(pickle.dumps(t)) == t
