@@ -1,7 +1,5 @@
 # BSD 3-Clause License; see https://github.com/scikit-hep/awkward-1.0/blob/main/LICENSE
 
-from __future__ import absolute_import
-
 import pytest  # noqa: F401
 import numpy as np  # noqa: F401
 import awkward as ak  # noqa: F401
@@ -50,12 +48,12 @@ def test_types_with_parameters():
     assert t.parameters == {"__array__": ["val", "ue"]}
 
     t = ak.types.UnknownType(
-        parameters={"key1": ["val", "ue"], "__record__": u"one \u2192 two"}
+        parameters={"key1": ["val", "ue"], "__record__": "one \u2192 two"}
     )
-    assert t.parameters == {"__record__": u"one \u2192 two", "key1": ["val", "ue"]}
+    assert t.parameters == {"__record__": "one \u2192 two", "key1": ["val", "ue"]}
 
     assert t == ak.types.UnknownType(
-        parameters={"__record__": u"one \u2192 two", "key1": ["val", "ue"]}
+        parameters={"__record__": "one \u2192 two", "key1": ["val", "ue"]}
     )
     assert t != ak.types.UnknownType(parameters={"__array__": ["val", "ue"]})
 
@@ -63,7 +61,7 @@ def test_types_with_parameters():
 def test_dress():
     class Dummy(ak.highlevel.Array):
         def __repr__(self):
-            return "<Dummy {0}>".format(str(self))
+            return f"<Dummy {str(self)}>"
 
     ns = {"Dummy": Dummy}
 
@@ -119,16 +117,10 @@ def test_builder_string():
     builder.bytestring(b"three")
 
     a = builder.snapshot()
-    if ak._util.py27:
-        assert str(a) == "['one', 'two', 'three']"
-    else:
-        assert str(a) == "[b'one', b'two', b'three']"
+    assert str(a) == "[b'one', b'two', b'three']"
     assert ak.to_list(a) == [b"one", b"two", b"three"]
     assert ak.to_json(a) == '["one","two","three"]'
-    if ak._util.py27:
-        assert repr(a) == "<Array ['one', 'two', 'three'] type='3 * bytes'>"
-    else:
-        assert repr(a) == "<Array [b'one', b'two', b'three'] type='3 * bytes'>"
+    assert repr(a) == "<Array [b'one', b'two', b'three'] type='3 * bytes'>"
     assert repr(ak.type(a)) == "3 * bytes"
 
     builder = ak.ArrayBuilder()
@@ -138,16 +130,10 @@ def test_builder_string():
     builder.string("three")
 
     a = builder.snapshot()
-    if ak._util.py27:
-        assert str(a) == "[u'one', u'two', u'three']"
-    else:
-        assert str(a) == "['one', 'two', 'three']"
+    assert str(a) == "['one', 'two', 'three']"
     assert ak.to_list(a) == ["one", "two", "three"]
     assert ak.to_json(a) == '["one","two","three"]'
-    if ak._util.py27:
-        assert repr(a) == "<Array [u'one', u'two', u'three'] type='3 * string'>"
-    else:
-        assert repr(a) == "<Array ['one', 'two', 'three'] type='3 * string'>"
+    assert repr(a) == "<Array ['one', 'two', 'three'] type='3 * string'>"
     assert repr(ak.type(a)) == "3 * string"
 
     builder = ak.ArrayBuilder()
@@ -167,10 +153,7 @@ def test_builder_string():
     builder.end_list()
 
     a = builder.snapshot()
-    if ak._util.py27:
-        assert str(a) == "[[u'one', u'two', u'three'], [], [u'four', u'five']]"
-    else:
-        assert str(a) == "[['one', 'two', 'three'], [], ['four', 'five']]"
+    assert str(a) == "[['one', 'two', 'three'], [], ['four', 'five']]"
     assert ak.to_list(a) == [["one", "two", "three"], [], ["four", "five"]]
     assert ak.to_json(a) == '[["one","two","three"],[],["four","five"]]'
     assert repr(ak.type(a)) == "3 * var * string"
