@@ -1,7 +1,5 @@
 # BSD 3-Clause License; see https://github.com/scikit-hep/awkward-1.0/blob/main/LICENSE
 
-from __future__ import absolute_import
-
 import pytest  # noqa: F401
 import numpy as np  # noqa: F401
 import awkward as ak  # noqa: F401
@@ -36,24 +34,23 @@ def test_axis0():
         (3.3, 400),
         (3.3, 500),
     ]
-    if not ak._util.py27 and not ak._util.py35:
-        assert ak.to_list(ak.cartesian({"x": one, "y": two}, axis=0)) == [
-            {"x": 1.1, "y": 100},
-            {"x": 1.1, "y": 200},
-            {"x": 1.1, "y": 300},
-            {"x": 1.1, "y": 400},
-            {"x": 1.1, "y": 500},
-            {"x": 2.2, "y": 100},
-            {"x": 2.2, "y": 200},
-            {"x": 2.2, "y": 300},
-            {"x": 2.2, "y": 400},
-            {"x": 2.2, "y": 500},
-            {"x": 3.3, "y": 100},
-            {"x": 3.3, "y": 200},
-            {"x": 3.3, "y": 300},
-            {"x": 3.3, "y": 400},
-            {"x": 3.3, "y": 500},
-        ]
+    assert ak.to_list(ak.cartesian({"x": one, "y": two}, axis=0)) == [
+        {"x": 1.1, "y": 100},
+        {"x": 1.1, "y": 200},
+        {"x": 1.1, "y": 300},
+        {"x": 1.1, "y": 400},
+        {"x": 1.1, "y": 500},
+        {"x": 2.2, "y": 100},
+        {"x": 2.2, "y": 200},
+        {"x": 2.2, "y": 300},
+        {"x": 2.2, "y": 400},
+        {"x": 2.2, "y": 500},
+        {"x": 3.3, "y": 100},
+        {"x": 3.3, "y": 200},
+        {"x": 3.3, "y": 300},
+        {"x": 3.3, "y": 400},
+        {"x": 3.3, "y": 500},
+    ]
     assert ak.to_list(ak.cartesian([one, two, three], axis=0)) == [
         (1.1, 100, "a"),
         (1.1, 100, "b"),
@@ -200,24 +197,23 @@ def test_axis1():
         [],
         [(3, 400), (3, 500), (4, 400), (4, 500)],
     ]
-    if not ak._util.py27 and not ak._util.py35:
-        assert ak.to_list(ak.cartesian({"x": one, "y": two})) == [
-            [
-                {"x": 0, "y": 100},
-                {"x": 0, "y": 200},
-                {"x": 1, "y": 100},
-                {"x": 1, "y": 200},
-                {"x": 2, "y": 100},
-                {"x": 2, "y": 200},
-            ],
-            [],
-            [
-                {"x": 3, "y": 400},
-                {"x": 3, "y": 500},
-                {"x": 4, "y": 400},
-                {"x": 4, "y": 500},
-            ],
-        ]
+    assert ak.to_list(ak.cartesian({"x": one, "y": two})) == [
+        [
+            {"x": 0, "y": 100},
+            {"x": 0, "y": 200},
+            {"x": 1, "y": 100},
+            {"x": 1, "y": 200},
+            {"x": 2, "y": 100},
+            {"x": 2, "y": 200},
+        ],
+        [],
+        [
+            {"x": 3, "y": 400},
+            {"x": 3, "y": 500},
+            {"x": 4, "y": 400},
+            {"x": 4, "y": 500},
+        ],
+    ]
 
     assert ak.to_list(ak.cartesian([one, two, three])) == [
         [
@@ -338,16 +334,15 @@ def test_argcartesian():
         [],
         [(0, 0), (0, 1), (1, 0), (1, 1)],
     ]
-    if not ak._util.py27 and not ak._util.py35:
-        assert ak.to_list(ak.argcartesian({"x": one, "y": two})) == [
-            [
-                {"x": 0, "y": 0},
-                {"x": 0, "y": 1},
-                {"x": 1, "y": 0},
-                {"x": 1, "y": 1},
-                {"x": 2, "y": 0},
-                {"x": 2, "y": 1},
-            ],
-            [],
-            [{"x": 0, "y": 0}, {"x": 0, "y": 1}, {"x": 1, "y": 0}, {"x": 1, "y": 1}],
-        ]
+    assert ak.to_list(ak.argcartesian({"x": one, "y": two})) == [
+        [
+            {"x": 0, "y": 0},
+            {"x": 0, "y": 1},
+            {"x": 1, "y": 0},
+            {"x": 1, "y": 1},
+            {"x": 2, "y": 0},
+            {"x": 2, "y": 1},
+        ],
+        [],
+        [{"x": 0, "y": 0}, {"x": 0, "y": 1}, {"x": 1, "y": 0}, {"x": 1, "y": 1}],
+    ]
