@@ -1,7 +1,5 @@
 # BSD 3-Clause License; see https://github.com/scikit-hep/awkward-1.0/blob/main/LICENSE
 
-from __future__ import absolute_import
-
 import pytest  # noqa: F401
 import numpy as np  # noqa: F401
 import awkward as ak  # noqa: F401
@@ -25,13 +23,11 @@ def test_string():
     assert f1(array, 1) == "two"
     assert f1(array, 2) == "three"
 
-    if not ak._util.py27:
+    def f2(x, i, j):
+        return x[i] + x[j]
 
-        def f2(x, i, j):
-            return x[i] + x[j]
-
-        assert f2(array, 1, 3) == "twofour"
-        assert numba.njit(f2)(array, 1, 3) == "twofour"
+    assert f2(array, 1, 3) == "twofour"
+    assert numba.njit(f2)(array, 1, 3) == "twofour"
 
 
 def test_bytestring():
