@@ -1,7 +1,5 @@
 # BSD 3-Clause License; see https://github.com/scikit-hep/awkward-1.0/blob/main/LICENSE
 
-from __future__ import absolute_import
-
 import pytest  # noqa: F401
 import numpy as np  # noqa: F401
 import awkward as ak  # noqa: F401
@@ -881,27 +879,25 @@ def test_arrow_null_nested_struct_nested_null():
 
 
 def test_arrow_strings():
-    if not ak._util.py27:
-        a = pyarrow.array(["one", "two", "three", u"fo\u2014ur", "five"])
-        assert ak.to_list(ak.from_arrow(a, highlevel=False)) == [
-            "one",
-            "two",
-            "three",
-            u"fo\u2014ur",
-            "five",
-        ]
+    a = pyarrow.array(["one", "two", "three", "fo\u2014ur", "five"])
+    assert ak.to_list(ak.from_arrow(a, highlevel=False)) == [
+        "one",
+        "two",
+        "three",
+        "fo\u2014ur",
+        "five",
+    ]
 
 
 def test_arrow_strings_null():
-    if not ak._util.py27:
-        a = pyarrow.array(["one", "two", None, u"fo\u2014ur", "five"])
-        assert ak.to_list(ak.from_arrow(a, highlevel=False)) == [
-            "one",
-            "two",
-            None,
-            u"fo\u2014ur",
-            "five",
-        ]
+    a = pyarrow.array(["one", "two", None, "fo\u2014ur", "five"])
+    assert ak.to_list(ak.from_arrow(a, highlevel=False)) == [
+        "one",
+        "two",
+        None,
+        "fo\u2014ur",
+        "five",
+    ]
 
 
 def test_arrow_binary():
