@@ -1,13 +1,6 @@
 # BSD 3-Clause License; see https://github.com/scikit-hep/awkward-1.0/blob/main/LICENSE
 
-from __future__ import absolute_import
-
-try:
-    # pybind11 only supports cPickle protocol 2+ (-1 in pickle.dumps)
-    # (automatically satisfied in Python 3; this is just to keep testing Python 2.7)
-    import cPickle as pickle
-except ImportError:
-    import pickle
+import pickle
 
 import pytest  # noqa: F401
 import numpy as np  # noqa: F401
@@ -192,21 +185,18 @@ def test_record():
     assert pickle.loads(
         pickle.dumps(ak.Record({"x": 2.2, "y": [1, 2]}), -1)
     ).tolist() == {"x": 2.2, "y": [1, 2]}
-    assert (
-        pickle.loads(
-            pickle.dumps(
-                ak.Array(
-                    [
-                        {"x": 1.1, "y": [1]},
-                        {"x": 2.2, "y": [1, 2]},
-                        {"x": 3.3, "y": [1, 2, 3]},
-                    ]
-                )[1],
-                -1,
-            )
-        ).tolist()
-        == {"x": 2.2, "y": [1, 2]}
-    )
+    assert pickle.loads(
+        pickle.dumps(
+            ak.Array(
+                [
+                    {"x": 1.1, "y": [1]},
+                    {"x": 2.2, "y": [1, 2]},
+                    {"x": 3.3, "y": [1, 2, 3]},
+                ]
+            )[1],
+            -1,
+        )
+    ).tolist() == {"x": 2.2, "y": [1, 2]}
 
 
 def test_regulararray():
