@@ -194,8 +194,8 @@ def test_nokeepdims_none1():
     axis2 = ak.sum(listoffset_regular, axis=-2)
     axis3 = ak.sum(listoffset_regular, axis=-3)
     assert str(ak.type(ak.Array(axis1))) == "2 * var * int64"
-    assert str(ak.type(ak.Array(axis2))) == "2 * var * int64"
-    assert str(ak.type(ak.Array(axis3))) == "3 * var * int64"
+    assert str(ak.type(ak.Array(axis2))) == "2 * 5 * int64"
+    assert str(ak.type(ak.Array(axis3))) == "3 * 5 * int64"
 
     assert str(ak.type(ak.Array(regular_listoffset))) == "2 * 3 * var * ?int64"
     axis1 = ak.sum(regular_listoffset, axis=-1)
@@ -210,8 +210,8 @@ def test_nokeepdims_none1():
     axis2 = ak.sum(regular_regular, axis=-2)
     axis3 = ak.sum(regular_regular, axis=-3)
     assert str(ak.type(ak.Array(axis1))) == "2 * 3 * int64"
-    assert str(ak.type(ak.Array(axis2))) == "2 * var * int64"
-    assert str(ak.type(ak.Array(axis3))) == "3 * var * int64"
+    assert str(ak.type(ak.Array(axis2))) == "2 * 5 * int64"
+    assert str(ak.type(ak.Array(axis3))) == "3 * 5 * int64"
 
 
 def test_keepdims_none1():
@@ -268,9 +268,9 @@ def test_keepdims_none1():
     axis1 = ak.sum(listoffset_regular, axis=-1, keepdims=True)
     axis2 = ak.sum(listoffset_regular, axis=-2, keepdims=True)
     axis3 = ak.sum(listoffset_regular, axis=-3, keepdims=True)
-    assert str(ak.type(ak.Array(axis1))) == "2 * var * var * int64"
-    assert str(ak.type(ak.Array(axis2))) == "2 * var * var * int64"
-    assert str(ak.type(ak.Array(axis3))) == "1 * var * var * int64"
+    assert str(ak.type(ak.Array(axis1))) == "2 * var * 1 * int64"
+    assert str(ak.type(ak.Array(axis2))) == "2 * var * 5 * int64"
+    assert str(ak.type(ak.Array(axis3))) == "1 * var * 5 * int64"
 
     assert str(ak.type(ak.Array(regular_listoffset))) == "2 * 3 * var * ?int64"
     axis1 = ak.sum(regular_listoffset, axis=-1, keepdims=True)
@@ -284,9 +284,9 @@ def test_keepdims_none1():
     axis1 = ak.sum(regular_regular, axis=-1, keepdims=True)
     axis2 = ak.sum(regular_regular, axis=-2, keepdims=True)
     axis3 = ak.sum(regular_regular, axis=-3, keepdims=True)
-    assert str(ak.type(ak.Array(axis1))) == "2 * 3 * var * int64"
-    assert str(ak.type(ak.Array(axis2))) == "2 * 1 * var * int64"
-    assert str(ak.type(ak.Array(axis3))) == "1 * 3 * var * int64"
+    assert str(ak.type(ak.Array(axis1))) == "2 * 3 * 1 * int64"
+    assert str(ak.type(ak.Array(axis2))) == "2 * 1 * 5 * int64"
+    assert str(ak.type(ak.Array(axis3))) == "1 * 3 * 5 * int64"
 
 
 def test_nokeepdims_mask1():
@@ -351,8 +351,8 @@ def test_nokeepdims_mask1():
     axis2 = ak.sum(listoffset_regular, axis=-2)
     axis3 = ak.sum(listoffset_regular, axis=-3)
     assert str(ak.type(ak.Array(axis1))) == "2 * var * int64"
-    assert str(ak.type(ak.Array(axis2))) == "2 * var * int64"
-    assert str(ak.type(ak.Array(axis3))) == "3 * var * int64"
+    assert str(ak.type(ak.Array(axis2))) == "2 * 5 * int64"
+    assert str(ak.type(ak.Array(axis3))) == "3 * 5 * int64"
 
     assert str(ak.type(ak.Array(regular_listoffset))) == "2 * 3 * var * ?int64"
     axis1 = ak.sum(regular_listoffset, axis=-1)
@@ -367,8 +367,8 @@ def test_nokeepdims_mask1():
     axis2 = ak.sum(regular_regular, axis=-2)
     axis3 = ak.sum(regular_regular, axis=-3)
     assert str(ak.type(ak.Array(axis1))) == "2 * 3 * int64"
-    assert str(ak.type(ak.Array(axis2))) == "2 * var * int64"
-    assert str(ak.type(ak.Array(axis3))) == "3 * var * int64"
+    assert str(ak.type(ak.Array(axis2))) == "2 * 5 * int64"
+    assert str(ak.type(ak.Array(axis3))) == "3 * 5 * int64"
 
 
 def test_keepdims_mask1():
@@ -432,9 +432,9 @@ def test_keepdims_mask1():
     axis1 = ak.sum(listoffset_regular, axis=-1, keepdims=True)
     axis2 = ak.sum(listoffset_regular, axis=-2, keepdims=True)
     axis3 = ak.sum(listoffset_regular, axis=-3, keepdims=True)
-    assert str(ak.type(ak.Array(axis1))) == "2 * var * var * int64"
-    assert str(ak.type(ak.Array(axis2))) == "2 * var * var * int64"
-    assert str(ak.type(ak.Array(axis3))) == "1 * var * var * int64"
+    assert str(ak.type(ak.Array(axis1))) == "2 * var * 1 * int64"
+    assert str(ak.type(ak.Array(axis2))) == "2 * var * 5 * int64"
+    assert str(ak.type(ak.Array(axis3))) == "1 * var * 5 * int64"
 
     assert str(ak.type(ak.Array(regular_listoffset))) == "2 * 3 * var * ?int64"
     axis1 = ak.sum(regular_listoffset, axis=-1, keepdims=True)
@@ -448,9 +448,9 @@ def test_keepdims_mask1():
     axis1 = ak.sum(regular_regular, axis=-1, keepdims=True)
     axis2 = ak.sum(regular_regular, axis=-2, keepdims=True)
     axis3 = ak.sum(regular_regular, axis=-3, keepdims=True)
-    assert str(ak.type(ak.Array(axis1))) == "2 * 3 * var * int64"
-    assert str(ak.type(ak.Array(axis2))) == "2 * 1 * var * int64"
-    assert str(ak.type(ak.Array(axis3))) == "1 * 3 * var * int64"
+    assert str(ak.type(ak.Array(axis1))) == "2 * 3 * 1 * int64"
+    assert str(ak.type(ak.Array(axis2))) == "2 * 1 * 5 * int64"
+    assert str(ak.type(ak.Array(axis3))) == "1 * 3 * 5 * int64"
 
 
 def test_nokeepdims_mask2():
@@ -482,14 +482,14 @@ def test_nokeepdims_mask2():
     axis2 = ak.sum(listoffset_regular, axis=-2)
     axis3 = ak.sum(listoffset_regular, axis=-3)
     assert str(ak.type(ak.Array(axis1))) == "2 * var * ?int64"
-    assert str(ak.type(ak.Array(axis2))) == "2 * var * int64"
-    assert str(ak.type(ak.Array(axis3))) == "3 * var * int64"
+    assert str(ak.type(ak.Array(axis2))) == "2 * 5 * int64"
+    assert str(ak.type(ak.Array(axis3))) == "3 * 5 * int64"
 
     assert str(ak.type(ak.Array(regular_listoffset))) == "2 * 3 * option[var * int64]"
     axis1 = ak.sum(regular_listoffset, axis=-1)
     axis2 = ak.sum(regular_listoffset, axis=-2)
     axis3 = ak.sum(regular_listoffset, axis=-3)
-    assert str(ak.type(ak.Array(axis1))) == "2 * var * ?int64"
+    assert str(ak.type(ak.Array(axis1))) == "2 * 3 * ?int64"
     assert str(ak.type(ak.Array(axis2))) == "2 * var * int64"
     assert str(ak.type(ak.Array(axis3))) == "3 * var * int64"
 
@@ -497,9 +497,9 @@ def test_nokeepdims_mask2():
     axis1 = ak.sum(regular_regular, axis=-1)
     axis2 = ak.sum(regular_regular, axis=-2)
     axis3 = ak.sum(regular_regular, axis=-3)
-    assert str(ak.type(ak.Array(axis1))) == "2 * var * ?int64"
-    assert str(ak.type(ak.Array(axis2))) == "2 * var * int64"
-    assert str(ak.type(ak.Array(axis3))) == "3 * var * int64"
+    assert str(ak.type(ak.Array(axis1))) == "2 * 3 * ?int64"
+    assert str(ak.type(ak.Array(axis2))) == "2 * 5 * int64"
+    assert str(ak.type(ak.Array(axis3))) == "3 * 5 * int64"
 
 
 def test_keepdims_mask2():
@@ -531,24 +531,24 @@ def test_keepdims_mask2():
     axis2 = ak.sum(listoffset_regular, axis=-2, keepdims=True)
     axis3 = ak.sum(listoffset_regular, axis=-3, keepdims=True)
     assert str(ak.type(ak.Array(axis1))) == "2 * var * option[1 * int64]"
-    assert str(ak.type(ak.Array(axis2))) == "2 * var * var * int64"
-    assert str(ak.type(ak.Array(axis3))) == "1 * var * var * int64"
+    assert str(ak.type(ak.Array(axis2))) == "2 * var * 5 * int64"
+    assert str(ak.type(ak.Array(axis3))) == "1 * var * 5 * int64"
 
     assert str(ak.type(ak.Array(regular_listoffset))) == "2 * 3 * option[var * int64]"
     axis1 = ak.sum(regular_listoffset, axis=-1, keepdims=True)
     axis2 = ak.sum(regular_listoffset, axis=-2, keepdims=True)
     axis3 = ak.sum(regular_listoffset, axis=-3, keepdims=True)
-    assert str(ak.type(ak.Array(axis1))) == "2 * var * option[var * int64]"
-    assert str(ak.type(ak.Array(axis2))) == "2 * var * var * int64"
-    assert str(ak.type(ak.Array(axis3))) == "1 * var * var * int64"
+    assert str(ak.type(ak.Array(axis1))) == "2 * 3 * option[var * int64]"
+    assert str(ak.type(ak.Array(axis2))) == "2 * 1 * var * int64"
+    assert str(ak.type(ak.Array(axis3))) == "1 * 3 * var * int64"
 
     assert str(ak.type(ak.Array(regular_regular))) == "2 * 3 * option[5 * int64]"
     axis1 = ak.sum(regular_regular, axis=-1, keepdims=True)
     axis2 = ak.sum(regular_regular, axis=-2, keepdims=True)
     axis3 = ak.sum(regular_regular, axis=-3, keepdims=True)
-    assert str(ak.type(ak.Array(axis1))) == "2 * var * option[1 * int64]"
-    assert str(ak.type(ak.Array(axis2))) == "2 * var * var * int64"
-    assert str(ak.type(ak.Array(axis3))) == "1 * var * var * int64"
+    assert str(ak.type(ak.Array(axis1))) == "2 * 3 * option[1 * int64]"
+    assert str(ak.type(ak.Array(axis2))) == "2 * 1 * 5 * int64"
+    assert str(ak.type(ak.Array(axis3))) == "1 * 3 * 5 * int64"
 
 
 def test_nokeepdims_mask3():
@@ -593,7 +593,7 @@ def test_nokeepdims_mask3():
     axis1 = ak.sum(regular_listoffset, axis=-1)
     axis2 = ak.sum(regular_listoffset, axis=-2)
     axis3 = ak.sum(regular_listoffset, axis=-3)
-    assert str(ak.type(ak.Array(axis1))) == "2 * option[var * int64]"
+    assert str(ak.type(ak.Array(axis1))) == "2 * option[3 * int64]"
     assert str(ak.type(ak.Array(axis2))) == "2 * option[var * int64]"
     assert str(ak.type(ak.Array(axis3))) == "3 * var * int64"
 
@@ -601,7 +601,7 @@ def test_nokeepdims_mask3():
     axis1 = ak.sum(regular_regular, axis=-1)
     axis2 = ak.sum(regular_regular, axis=-2)
     axis3 = ak.sum(regular_regular, axis=-3)
-    assert str(ak.type(ak.Array(axis1))) == "2 * option[var * int64]"
+    assert str(ak.type(ak.Array(axis1))) == "2 * option[3 * int64]"
     assert str(ak.type(ak.Array(axis2))) == "2 * option[5 * int64]"
     assert str(ak.type(ak.Array(axis3))) == "3 * 5 * int64"
 
@@ -648,14 +648,14 @@ def test_keepdims_mask3():
     axis1 = ak.sum(regular_listoffset, axis=-1, keepdims=True)
     axis2 = ak.sum(regular_listoffset, axis=-2, keepdims=True)
     axis3 = ak.sum(regular_listoffset, axis=-3, keepdims=True)
-    assert str(ak.type(ak.Array(axis1))) == "2 * option[var * var * int64]"
-    assert str(ak.type(ak.Array(axis2))) == "2 * option[var * var * int64]"
-    assert str(ak.type(ak.Array(axis3))) == "1 * var * var * int64"
+    assert str(ak.type(ak.Array(axis1))) == "2 * option[3 * var * int64]"
+    assert str(ak.type(ak.Array(axis2))) == "2 * option[1 * var * int64]"
+    assert str(ak.type(ak.Array(axis3))) == "1 * 3 * var * int64"
 
     assert str(ak.type(ak.Array(regular_regular))) == "2 * option[3 * 5 * int64]"
     axis1 = ak.sum(regular_regular, axis=-1, keepdims=True)
     axis2 = ak.sum(regular_regular, axis=-2, keepdims=True)
     axis3 = ak.sum(regular_regular, axis=-3, keepdims=True)
-    assert str(ak.type(ak.Array(axis1))) == "2 * option[var * 1 * int64]"
-    assert str(ak.type(ak.Array(axis2))) == "2 * option[var * 5 * int64]"
-    assert str(ak.type(ak.Array(axis3))) == "1 * var * 5 * int64"
+    assert str(ak.type(ak.Array(axis1))) == "2 * option[3 * 1 * int64]"
+    assert str(ak.type(ak.Array(axis2))) == "2 * option[1 * 5 * int64]"
+    assert str(ak.type(ak.Array(axis3))) == "1 * 3 * 5 * int64"
